@@ -8,17 +8,15 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_iam._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import cdk8s._jsii
-import cdk8s_plus_17._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@opencdk8s/cdk8s-aws-lb-controller",
-    "0.2.3",
+    "0.2.5",
     __name__[0:-6],
-    "cdk8s-aws-lb-controller@0.2.3.jsii.tgz",
+    "cdk8s-aws-lb-controller@0.2.5.jsii.tgz",
 )
 
 __all__ = [
